@@ -1,12 +1,12 @@
 pub mod h264_reader;
 pub mod h264_writer;
+use crate::error::Result;
+
 pub mod ivf_reader;
 pub mod ivf_writer;
 pub mod ogg_reader;
 pub mod ogg_writer;
 
-use anyhow::Result;
-
 pub type ResetFn<R> = Box<dyn FnMut(usize) -> R>;
 
 // Writer defines an interface to handle
